@@ -1,21 +1,23 @@
 var fs = require('fs');
+var http = require('http');
+
 // Serve client side statically
 var express = require('express');
-var app = express.createServer().listen(9000);
+var app = express();
 app.use(express.static(__dirname + '/public'));
 
+var server = http.createServer(app);
+
 // Start Binary.js server
-var BinaryServer = require('binaryjs').BinaryServer;
-var server = BinaryServer({port: 9001});
+var BinaryServer = require('../../').BinaryServer;
+var bs = BinaryServer({server: server});
 
-//
-//
 // Wait for new user connections
-server.on('connection', function(client){
+bs.on('connection', function(client){
   // Incoming stream from browsers
   client.on('stream', function(stream, meta){
     //
-    var file = fs.createWriteStream(__dirname+ '/' + meta.name);
+    var file = fs.createWriteStream(__dirname+ '/public/' + meta.name);
     stream.pipe(file);
     //
     // Send progress back
@@ -28,5 +30,5 @@ server.on('connection', function(client){
 //
 //
 
-console.log('HTTP server started on port 9000');
-console.log('BinaryJS server started on port 9001');
\ No newline at end of file
+server.listen(9000);
+console.log('HTTP and BinaryJS server started on port 9000');
