@@ -1,6 +1,6 @@
-var BinaryServer = require('binaryjs').BinaryServer;
+var BinaryServer = require('../../').BinaryServer;
 var fs = require('fs');
-i = 0;
+
 // Start Binary.js server
 var server = BinaryServer({port: 9000});
 // Wait for new user connections
@@ -8,6 +8,5 @@ server.on('connection', function(client){
   // Stream a flower as a hello!
   var file = fs.createReadStream(__dirname + '/flower.png');
   client.send(file); 
- 
 });
 
