@@ -69,6 +69,9 @@ BinaryStream.prototype._onResume = function() {
 };
 
 BinaryStream.prototype._write = function(code, data, bonus) {
+  if (this._socket.readyState !== this._socket.constructor.OPEN) {
+    return false;
+  }
   var message = util.pack([code, data, bonus]);
   return this._socket.send(message) !== false;
 };
